@@ -46,17 +46,16 @@ public:
 		
 private:
 	void on_signal_update( const OperationDetail & operationdetail ) ;
-	void dispatcher_on_update_gui_elements() ;
+	void update_gui_elements() ;
 	void on_signal_show() ;
-	void on_expander_changed() ;
 	void on_cell_data_description( Gtk::CellRenderer * renderer, const Gtk::TreeModel::iterator & iter) ;
-	static void *static_pthread_apply_operation( void * p_dialog_progress ) ;
 	void on_cancel() ;
 	void on_save() ;
 	void echo_operation_details( const OperationDetail & operation_detail, std::ofstream & out ) ;
 	
 	void on_response( int response_id ) ;
 	bool on_delete_event( GdkEventAny * event ) ;
+	bool pulsebar_pulse();
 
 	Gtk::Label label_current ;
 	Gtk::Label label_current_sub ;
@@ -65,6 +64,7 @@ private:
 	Gtk::TreeRow treerow ;
 	Gtk::ScrolledWindow scrolledwindow ;
 	Gtk::Expander expander_details ;
+	Gtk::Button *cancelbutton;
 	
 	Glib::RefPtr<Gdk::Pixbuf> icon_execute ;
 	Glib::RefPtr<Gdk::Pixbuf> icon_succes ;
@@ -91,13 +91,14 @@ private:
 	
 	std::vector<Operation *> operations ;
 	OperationDetail operationdetail ;
-	bool running, succes, cancel, pulse ;
-	pthread_t pthread ;
+	bool succes, cancel;
 	double fraction ;
 	unsigned int t, warnings ;
-
-	Glib::Dispatcher dispatcher_update_gui_elements ;
+	sigc::connection pulsetimer;
 	Glib::ustring label_current_sub_text ;
+	unsigned int cancel_countdown;
+	sigc::connection canceltimer;
+	bool cancel_timeout();
 };
 
 }//GParted
