@@ -42,6 +42,7 @@ public:
 	void find_supported_filesystems() ;
 	void set_user_devices( const std::vector<Glib::ustring> & user_devices ) ;
 	void set_devices( std::vector<Device> & devices ) ;
+	void set_devices_thread( std::vector<Device> * pdevices );
 	void guess_partition_table(const Device & device, Glib::ustring &buff);
 	
 	bool snap_to_cylinder( const Device & device, Partition & partition, Glib::ustring & error ) ;
@@ -139,17 +140,16 @@ private:
 		   Partition & partition_dst,
 		   Byte_Value min_size,
 		   OperationDetail & operationdetail ) ; 
-	bool copy_filesystem_simulation( const Partition & partition_src,
-			      		 const Partition & partition_dst,
-			      		 OperationDetail & operationdetail ) ;
 	bool copy_filesystem( const Partition & partition_src,
 			      const Partition & partition_dst,
 			      OperationDetail & operationdetail,
-			      bool readonly = false ) ;
+			      bool readonly,
+			      bool cancel_safe );
 	bool copy_filesystem( const Partition & partition_src,
 			      const Partition & partition_dst,
 			      OperationDetail & operationdetail,
-			      Byte_Value & total_done ) ;
+			      Byte_Value & total_done,
+			      bool cancel_safe );
 	bool copy_filesystem( const Glib::ustring & src_device,
 			      const Glib::ustring & dst_device,
 			      Sector src_start,
@@ -159,7 +159,8 @@ private:
 			      Byte_Value src_length,
 			      OperationDetail & operationdetail,
 			      bool readonly,
-			      Byte_Value & total_done ) ;
+			      Byte_Value & total_done,
+			      bool cancel_safe ) ;
 	void rollback_transaction( const Partition & partition_src,
 				   const Partition & partition_dst,
 				   OperationDetail & operationdetail,
@@ -169,41 +170,18 @@ private:
 
 	bool set_partition_type( const Partition & partition, OperationDetail & operationdetail ) ;
 
-	void set_progress_info( Sector total, Sector done, const Glib::Timer & timer, OperationDetail & operationdetail, bool readonly ) ;
-
-	bool copy_blocks( const Glib::ustring & src_device,
-			  const Glib::ustring & dst_device,
-			  Sector src_start,
-			  Sector dst_start,
-			  Byte_Value length,
-			  Byte_Value blocksize,
-			  OperationDetail & operationdetail,
-			  bool readonly,
-			  Byte_Value & total_done ) ;
-
-	bool copy_block( PedDevice * lp_device_src,
-			 PedDevice * lp_device_dst,
-			 Sector offset_src,
-			 Sector offset_dst,
-			 Byte_Value blocksize,
-			 Glib::ustring & error_message,
-			 bool readonly ) ; 
 	bool calibrate_partition( Partition & partition, OperationDetail & operationdetail ) ;
 	bool calculate_exact_geom( const Partition & partition_old,
 			           Partition & partition_new,
 				   OperationDetail & operationdetail ) ;
 	FileSystem* set_proper_filesystem( const FILESYSTEM & filesystem ) ;
-#ifndef HAVE_LIBPARTED_3_0_0_PLUS
-	bool erase_filesystem_signatures( const Partition & partition ) ;
-#endif
+	bool erase_filesystem_signatures( const Partition & partition, OperationDetail & operationdetail ) ;
 	bool update_bootsector( const Partition & partition, OperationDetail & operationdetail ) ;
 
 	//general..	
-	PedDevice* open_device( const Glib::ustring & device_path ) ;
-	bool open_device_and_disk( const Glib::ustring & device_path,
-	                           PedDevice*& lp_device, PedDisk*& lp_disk, bool strict = true ) ;
-	void close_disk( PedDisk*& lp_disk ) ;
-	void close_device_and_disk( PedDevice*& lp_device, PedDisk*& lp_disk ) ;
+	bool get_device_and_disk( const Glib::ustring & device_path,
+	                          PedDevice*& lp_device, PedDisk*& lp_disk, bool strict = true ) ;
+	void destroy_device_and_disk( PedDevice*& lp_device, PedDisk*& lp_disk ) ;
 	bool commit( PedDisk* lp_disk ) ;
 	bool commit_to_os( PedDisk* lp_disk, std::time_t timeout ) ;
 	void settle_device( std::time_t timeout ) ;
