@@ -32,7 +32,8 @@ enum OperationType {
 	OPERATION_RESIZE_MOVE	= 3,
 	OPERATION_FORMAT	= 4,
 	OPERATION_COPY		= 5,
-	OPERATION_LABEL_PARTITION = 6
+	OPERATION_LABEL_PARTITION = 6,
+	OPERATION_CHANGE_UUID	= 7
 };
 
 class Operation
