@@ -59,31 +59,33 @@ enum FILESYSTEM
 	FS_UNALLOCATED	= 0,
 	FS_UNKNOWN	= 1,
 	FS_UNFORMATTED	= 2,
-	FS_EXTENDED	= 3,
+	FS_CLEARED	= 3,  //Clear existing file system signatures
+	FS_EXTENDED	= 4,
 
-	FS_BTRFS	= 4,
-	FS_EXFAT	= 5, /* Also known as fat64 */
-	FS_EXT2		= 6,
-	FS_EXT3		= 7,
-	FS_EXT4		= 8,
-	FS_FAT16	= 9,
-	FS_FAT32	= 10,
-	FS_HFS		= 11,
-	FS_HFSPLUS	= 12,
-	FS_JFS		= 13,
-	FS_LINUX_SWAP	= 14,
-	FS_LVM2_PV	= 15,
-	FS_NILFS2	= 16,
-	FS_NTFS		= 17,
-	FS_REISER4	= 18,
-	FS_REISERFS	= 19,
-	FS_UFS		= 20,
-	FS_XFS		= 21,
+	FS_BTRFS	= 5,
+	FS_EXFAT	= 6, /* Also known as fat64 */
+	FS_EXT2		= 7,
+	FS_EXT3		= 8,
+	FS_EXT4		= 9,
+	FS_F2FS		= 10,
+	FS_FAT16	= 11,
+	FS_FAT32	= 12,
+	FS_HFS		= 13,
+	FS_HFSPLUS	= 14,
+	FS_JFS		= 15,
+	FS_LINUX_SWAP	= 16,
+	FS_LVM2_PV	= 17,
+	FS_NILFS2	= 18,
+	FS_NTFS		= 19,
+	FS_REISER4	= 20,
+	FS_REISERFS	= 21,
+	FS_UFS		= 22,
+	FS_XFS		= 23,
 
-	FS_USED		= 22,
-	FS_UNUSED	= 23,
+	FS_USED		= 24,
+	FS_UNUSED	= 25,
 
-	FS_LUKS		= 24
+	FS_LUKS		= 26
 } ;
 
 enum SIZE_UNIT
@@ -158,6 +160,7 @@ public:
 	static Glib::ustring num_to_str( Sector number ) ;
 	static Glib::ustring get_color( FILESYSTEM filesystem ) ;
 	static Glib::RefPtr<Gdk::Pixbuf> get_color_as_pixbuf( FILESYSTEM filesystem, int width, int height ) ;
+	static int get_filesystem_label_maxlength( FILESYSTEM filesystem ) ;
 	static Glib::ustring get_filesystem_string( FILESYSTEM filesystem ) ;
 	static Glib::ustring get_filesystem_software( FILESYSTEM filesystem ) ;
 	static bool kernel_supports_fs( const Glib::ustring & fs ) ;
@@ -173,12 +176,10 @@ public:
 	static Glib::ustring regexp_label( const Glib::ustring & text
 	                                 , const Glib::ustring & pattern
 	                                 ) ;
-	static Glib::ustring fat_compliant_label( const Glib::ustring & label ) ;
 	static Glib::ustring create_mtoolsrc_file( char file_name[],
                     const char drive_letter, const Glib::ustring & device_path ) ;
 	static Glib::ustring delete_mtoolsrc_file( const char file_name[] ) ;
 	static Glib::ustring trim( const Glib::ustring & src, const Glib::ustring & c = " \t\r\n" ) ;
-	static Glib::ustring cleanup_cursor( const Glib::ustring & text ) ;
 	static Glib::ustring get_lang() ;
 	static void tokenize( const Glib::ustring& str,
 	                      std::vector<Glib::ustring>& tokens,
@@ -196,7 +197,6 @@ private:
 	static bool get_kernel_version( int & major_ver, int & minor_ver, int & patch_ver ) ;
 };
 
-
 }//GParted
 
 #endif //UTILS
