@@ -123,10 +123,10 @@ void DialogFeatures::load_filesystems( const std::vector<FS> & FILESYSTEMS )
 	//fill the features chart with valid file systems 
 	for ( unsigned short t = 0; t < FILESYSTEMS .size() ; t++ )
 	{
-		//Skip luks and unknown because these are not file systems
-		if (
-		     FILESYSTEMS[ t ] .filesystem == GParted::FS_LUKS    ||
-		     FILESYSTEMS[ t ] .filesystem == GParted::FS_UNKNOWN
+		//Skip unknown, cleared and luks because these are not file systems
+		if (    FILESYSTEMS[ t ] .filesystem == FS_UNKNOWN
+		     || FILESYSTEMS[ t ] .filesystem == FS_CLEARED
+		     || FILESYSTEMS[ t ] .filesystem == FS_LUKS
 		   )
 			continue ;
 		show_filesystem( FILESYSTEMS[ t ] ) ;
