@@ -17,6 +17,7 @@
  */
  
 #include "../include/Dialog_Partition_Resize_Move.h"
+#include "../include/GParted_Core.h"
 
 namespace GParted
 {
@@ -63,11 +64,19 @@ void Dialog_Partition_Resize_Move::Set_Data( const Partition & selected_partitio
 void Dialog_Partition_Resize_Move::Resize_Move_Normal( const std::vector<Partition> & partitions )
 {
 	//little bit of paranoia ;)
-	if ( selected_partition .sectors_used == -1 && 
+	if ( ! selected_partition .sector_usage_known() &&
 	     selected_partition .status != STAT_NEW &&
 	     selected_partition .filesystem != FS_LINUX_SWAP )
 		fs .shrink = GParted::FS::NONE ;
 	
+	//Disable resizing as it's currently disallowed for the file system in this partition.
+	//  (Updates this class's copy of file system support information).
+	if ( GParted_Core::filesystem_resize_disallowed( selected_partition ) )
+	{
+		fs .shrink = FS::NONE ;
+		fs .grow   = FS::NONE ;
+	}
+
 	//see if we need a fixed_start
 	if ( fs .move )
 	{
@@ -148,14 +157,15 @@ void Dialog_Partition_Resize_Move::Resize_Move_Normal( const std::vector<Partiti
 	frame_resizer_base ->set_x_start( Utils::round( previous / ( total_length / 500.00 ) ) ) ;
 	frame_resizer_base ->set_x_end( 
 		Utils::round( selected_partition .get_sector_length() / ( total_length / 500.00 ) ) + frame_resizer_base ->get_x_start() ) ;
-	frame_resizer_base ->set_used( Utils::round( selected_partition.sectors_used / ( total_length / 500.00 ) ) ) ;
+	Sector min_resize = selected_partition .estimated_min_size() ;
+	frame_resizer_base ->set_used( Utils::round( min_resize / ( total_length / 500.00 ) ) ) ;
 
 	//set MIN
 	if ( fs .shrink )
 	{
 		//since some file systems have lower limits we need to check for this
-		if ( selected_partition .sectors_used > (fs .MIN / selected_partition .sector_size) )
-			fs .MIN = selected_partition .sectors_used * selected_partition .sector_size ;
+		if ( min_resize > (fs .MIN / selected_partition .sector_size) )
+			fs .MIN = min_resize * selected_partition .sector_size ;
 
 		//ensure that minimum size is at least one mebibyte
 		if ( ! fs .MIN || fs .MIN < MEBIBYTE )
