@@ -22,6 +22,7 @@
 #include <cerrno>
 #include <iostream>
 #include <gtkmm/main.h>
+#include <signal.h>
 #include <fcntl.h>
 
 namespace GParted
@@ -88,7 +89,7 @@ int FileSystem::execute_command( const Glib::ustring & command, OperationDetail
 	running = true;
 	try {
 		Glib::spawn_async_with_pipes(
-			std::string(),
+			std::string( "." ),
 			Glib::shell_parse_argv( command ),
 			Glib::SPAWN_DO_NOT_REAP_CHILD | Glib::SPAWN_SEARCH_PATH,
 			sigc::ptr_fun(setup_child),
@@ -123,8 +124,8 @@ int FileSystem::execute_command( const Glib::ustring & command, OperationDetail
 	errorcapture.update.connect( sigc::bind( sigc::ptr_fun( relay_update ),
 						 &(children[children.size() - 1]),
 						 &error ) );
-	outputcapture.connect_signal( out );
-	errorcapture.connect_signal( err );
+	outputcapture.connect_signal();
+	errorcapture.connect_signal();
 
 	operationdetail.get_last_child().signal_cancel.connect(
 		sigc::bind(
