@@ -22,22 +22,21 @@
 namespace GParted
 {
 
-OperationDetail::OperationDetail()
+OperationDetail::OperationDetail() : fraction( -1 ), cancelflag( 0 ), status( STATUS_NONE ), time_start( -1 ),
+				     time_elapsed( -1 )
 {
-	status = STATUS_NONE; // prevent uninitialized member access
-	set_status( STATUS_NONE ) ;
-	fraction = -1 ;
-	time_elapsed = -1 ;
 }
 
-OperationDetail::OperationDetail( const Glib::ustring & description, OperationDetailStatus status, Font font )
+OperationDetail::OperationDetail( const Glib::ustring & description, OperationDetailStatus status, Font font ) :
+	fraction( -1 ), cancelflag( 0 ), status( STATUS_NONE ), time_start( -1 ), time_elapsed( -1 )
 {
-	this ->status = STATUS_NONE; // prevent uninitialized member access
-	set_description( description, font ) ;
-	set_status( status ) ;
+	set_description( description, font );
+	set_status( status );
+}
 
-	fraction = -1 ;
-	time_elapsed = -1 ;
+OperationDetail::~OperationDetail()
+{
+	cancelconnection.disconnect();
 }
 
 void OperationDetail::set_description( const Glib::ustring & description, Font font )
@@ -85,7 +84,8 @@ void OperationDetail::set_status( OperationDetailStatus status )
 				break ;
 			case STATUS_ERROR:
 			case STATUS_SUCCES:
-				time_elapsed = std::time( NULL ) - time_start ;
+				if( time_start != -1 )
+					time_elapsed = std::time( NULL ) - time_start ;
 				break ;
 
 			default:
@@ -126,7 +126,10 @@ void OperationDetail::add_child( const OperationDetail & operationdetail )
 
 	sub_details .back() .set_treepath( treepath + ":" + Utils::num_to_str( sub_details .size() -1 ) ) ;
 	sub_details .back() .signal_update .connect( sigc::mem_fun( this, &OperationDetail::on_update ) ) ;
-	
+	sub_details.back().cancelconnection = signal_cancel.connect(
+				sigc::mem_fun( &sub_details.back(), &OperationDetail::cancel ) );
+	if ( cancelflag )
+		sub_details.back().cancel( cancelflag == 2 );
 	on_update( sub_details .back() ) ;
 }
 	
@@ -146,7 +149,7 @@ OperationDetail & OperationDetail::get_last_child()
 	if ( sub_details .size() == 0 )
 		add_child( OperationDetail( "---", STATUS_ERROR ) ) ;
 
-	return sub_details .back() ;
+	return sub_details[sub_details.size() - 1];
 }
 
 void OperationDetail::on_update( const OperationDetail & operationdetail ) 
@@ -155,4 +158,12 @@ void OperationDetail::on_update( const OperationDetail & operationdetail )
 		signal_update .emit( operationdetail ) ;
 }
 
+void OperationDetail::cancel( bool force )
+{
+	if ( force )
+		cancelflag = 2;
+	else cancelflag = 1;
+	signal_cancel(force);
+}
+
 } //GParted
