@@ -166,27 +166,6 @@ bool btrfs::write_label( const Partition & partition, OperationDetail & operatio
 	return ! execute_command( "btrfs filesystem label " + partition .get_path() + " \"" + partition .get_label() + "\"", operationdetail ) ;
 }
 
-bool btrfs::write_uuid( const Partition & partition, OperationDetail & operationdetail )
-{
-	return true ;
-}
-
-bool btrfs::move( const Partition & partition_new
-                , const Partition & partition_old
-                , OperationDetail & operationdetail
-                )
-{
-	return true ;
-}
-
-bool btrfs::copy( const Glib::ustring & src_part_path,
-                    const Glib::ustring & dest_part_path,
-                    OperationDetail & operationdetail )
-{
-// TODO
-        return true ;
-}
-
 bool btrfs::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
 {
 	bool success = true ;
@@ -195,7 +174,8 @@ bool btrfs::resize( const Partition & partition_new, OperationDetail & operation
 	if ( mount_point .empty() )
 		return false ;
 
-	success &= ! execute_command_timed( "mount -v -t btrfs " + partition_new .get_path() + " " + mount_point, operationdetail ) ;
+	success &= ! execute_command( "mount -v -t btrfs " + partition_new .get_path() + " " + mount_point,
+				      operationdetail, true ) ;
 
 	if ( success )
 	{
@@ -210,7 +190,7 @@ bool btrfs::resize( const Partition & partition_new, OperationDetail & operation
 			cmd = "btrfs filesystem resize " + size + " " + mount_point ;
 		else
 			cmd = "btrfsctl -r " + size + " " + mount_point ;
-		exit_status = execute_command_timed( cmd, operationdetail, false ) ;
+		exit_status = execute_command( cmd, operationdetail, false ) ;
 		bool resize_succeeded = ( exit_status == 0 ) ;
 		if ( resize_to_same_size_fails )
 		{
@@ -235,7 +215,7 @@ bool btrfs::resize( const Partition & partition_new, OperationDetail & operation
 		operationdetail .get_last_child() .set_status( resize_succeeded ? STATUS_SUCCES : STATUS_ERROR ) ;
 		success &= resize_succeeded ;
 
-		success &= ! execute_command_timed( "umount -v " + mount_point, operationdetail ) ;
+		success &= ! execute_command( "umount -v " + mount_point, operationdetail, true ) ;
 	}
 
 	rm_temp_dir( mount_point, operationdetail ) ;
@@ -312,11 +292,6 @@ void btrfs::read_uuid( Partition & partition )
 	}
 }
 
-bool btrfs::remove( const Partition & partition, OperationDetail & operationdetail )
-{
-	return true ;
-}
-
 //Private methods
 
 //Return the value of a btrfs tool formatted size, including reversing
