@@ -50,7 +50,10 @@ FS fat32::get_filesystem_support()
 {
 	FS fs ;
 	fs .filesystem = GParted::FS_FAT32 ;
-		
+
+	// hack to disable silly mtools warnings
+	setenv( "MTOOLS_SKIP_CHECK", "1", 0 );
+
 	//find out if we can create fat32 file systems
 	if ( ! Glib::find_program_in_path( "mkdosfs" ) .empty() )
 		fs .create = GParted::FS::EXTERNAL ;
@@ -138,15 +141,7 @@ void fat32::set_used_sectors( Partition & partition )
 
 void fat32::read_label( Partition & partition )
 {
-	//Create mtools config file
-	char fname[] = "/tmp/gparted-XXXXXXXX" ;
-	char dletter = 'H' ;
-	Glib::ustring err_msg = "" ;
-	err_msg = Utils::create_mtoolsrc_file( fname, dletter, partition.get_path() ) ;
-	if( err_msg.length() != 0 )
-		partition .messages .push_back( err_msg );
-
-	Glib::ustring cmd = String::ucompose( "export MTOOLSRC=%1 && mlabel -s %2:", fname, dletter ) ;
+	Glib::ustring cmd = "mlabel -s :: -i " + partition.get_path();
 
 	if ( ! Utils::execute_command( cmd, output, error, true ) )
 	{
@@ -160,27 +155,18 @@ void fat32::read_label( Partition & partition )
 		if ( ! error .empty() )
 			partition .messages .push_back( error ) ;
 	}
-	
-	//Delete mtools config file
-	err_msg = Utils::delete_mtoolsrc_file( fname );
 }
 
 bool fat32::write_label( const Partition & partition, OperationDetail & operationdetail )
 {
-	//Create mtools config file
-	char fname[] = "/tmp/gparted-XXXXXXXX" ;
-	char dletter = 'H' ;
-	Glib::ustring err_msg = "" ;
-	err_msg = Utils::create_mtoolsrc_file( fname, dletter, partition.get_path() ) ;
-
 	Glib::ustring cmd = "" ;
 	if ( partition .get_label() .empty() )
-		cmd = String::ucompose( "export MTOOLSRC=%1 && mlabel -c %2:", fname, dletter ) ;
+		cmd = "mlabel -c :: -i " + partition.get_path();
 	else
-		cmd = String::ucompose( "export MTOOLSRC=%1 && mlabel %2:\"%3\"",
-		                        fname, dletter, Utils::fat_compliant_label( partition .get_label() ) ) ;
+		cmd = "mlabel ::\"" + partition.get_label() + "\" -i " + partition.get_path();
+
 	operationdetail .add_child( OperationDetail( cmd, STATUS_NONE, FONT_BOLD_ITALIC ) ) ;
-	
+
 	int exit_status = Utils::execute_command( cmd, output, error ) ;
 
 	if ( ! output .empty() )
@@ -189,23 +175,12 @@ bool fat32::write_label( const Partition & partition, OperationDetail & operatio
 	if ( ! error .empty() )
 		operationdetail .get_last_child() .add_child( OperationDetail( error, STATUS_NONE, FONT_ITALIC ) ) ;
 
-	//Delete mtools config file
-	err_msg = Utils::delete_mtoolsrc_file( fname );
-
 	return ( exit_status == 0 );
 }
 
 void fat32::read_uuid( Partition & partition )
 {
-	//Create mtools config file
-	char fname[] = "/tmp/gparted-XXXXXXXX" ;
-	char dletter = 'H' ;
-	Glib::ustring err_msg = "" ;
-	err_msg = Utils::create_mtoolsrc_file( fname, dletter, partition.get_path() ) ;
-	if( err_msg.length() != 0 )
-		partition .messages .push_back( err_msg );
-
-	Glib::ustring cmd = String::ucompose( "export MTOOLSRC=%1 && mdir -f %2:", fname, dletter ) ;
+	Glib::ustring cmd = "mdir -f :: -i " + partition.get_path();
 
 	if ( ! Utils::execute_command( cmd, output, error, true ) )
 	{
@@ -221,22 +196,12 @@ void fat32::read_uuid( Partition & partition )
 		if ( ! error .empty() )
 			partition .messages .push_back( error ) ;
 	}
-
-	err_msg = Utils::delete_mtoolsrc_file( fname );
 }
 
 
 bool fat32::write_uuid( const Partition & partition, OperationDetail & operationdetail )
 {
-	//Create mtools config file
-	char fname[] = "/tmp/gparted-XXXXXXXX" ;
-	char dletter = 'H' ;
-	Glib::ustring err_msg = "" ;
-	err_msg = Utils::create_mtoolsrc_file( fname, dletter, partition.get_path() ) ;
-
-	// Wait some time - 'random' UUIDs turn out identical if generated in quick succession...
-	sleep(1);
-	Glib::ustring cmd = String::ucompose( "export MTOOLSRC=%1 && mlabel -s -n %2:", fname, dletter ) ;
+	Glib::ustring cmd = "mlabel -s -n :: -i " + partition.get_path();
 
 	operationdetail .add_child( OperationDetail( cmd, STATUS_NONE, FONT_BOLD_ITALIC ) ) ;
 
@@ -248,48 +213,22 @@ bool fat32::write_uuid( const Partition & partition, OperationDetail & operation
 	if ( ! error .empty() )
 		operationdetail .get_last_child() .add_child( OperationDetail( error, STATUS_NONE, FONT_ITALIC ) ) ;
 
-	//Delete mtools config file
-	err_msg = Utils::delete_mtoolsrc_file( fname );
-
 	return ( exit_status == 0 );
 }
 
 bool fat32::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "mkdosfs -F32 -v -n \"" + Utils::fat_compliant_label( new_partition .get_label() ) +
-	                          "\" " + new_partition .get_path(), operationdetail ) ;
-}
-
-bool fat32::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
-{
-	return true ;
-}
-
-bool fat32::move( const Partition & partition_new
-                , const Partition & partition_old
-                , OperationDetail & operationdetail
-                )
-{
-	return true ;
-}
-
-bool fat32::copy( const Glib::ustring & src_part_path, 
-		  const Glib::ustring & dest_part_path,
-		  OperationDetail & operationdetail )
-{
-	return true ;
+	return ! execute_command( "mkdosfs -F32 -v -I -n \"" + new_partition.get_label() +
+				  "\" " + new_partition.get_path(), operationdetail,
+				  false, true );
 }
 
 bool fat32::check_repair( const Partition & partition, OperationDetail & operationdetail )
 {
-	exit_status = execute_command( "dosfsck -a -w -v " + partition .get_path(), operationdetail ) ;
+	exit_status = execute_command( "dosfsck -a -w -v " + partition.get_path(), operationdetail,
+				       false, true );
 
 	return ( exit_status == 0 || exit_status == 1 || exit_status == 256 ) ;
 }
 
-bool fat32::remove( const Partition & partition, OperationDetail & operationdetail )
-{
-	return true ;
-}
-
 } //GParted
