@@ -51,10 +51,6 @@ FS hfs::get_filesystem_support()
 	return fs ;
 }
 
-void hfs::set_used_sectors( Partition & partition ) 
-{
-}
-
 void hfs::read_label( Partition & partition )
 {
 	if ( ! Utils::execute_command( "vol_id " + partition .get_path(), output, error, true ) )
@@ -76,20 +72,6 @@ void hfs::read_label( Partition & partition )
 	}
 }
 
-bool hfs::write_label( const Partition & partition, OperationDetail & operationdetail )
-{
-	return true ;
-}
-
-void hfs::read_uuid( Partition & partition )
-{
-}
-
-bool hfs::write_uuid( const Partition & partition, OperationDetail & operationdetail )
-{
-	return true ;
-}
-
 bool hfs::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
 	Glib::ustring cmd = "";
@@ -100,35 +82,10 @@ bool hfs::create( const Partition & new_partition, OperationDetail & operationde
 	return ! execute_command( cmd , operationdetail ) ;
 }
 
-bool hfs::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
-{
-	return true ;
-}
-
-bool hfs::move( const Partition & partition_new
-              , const Partition & partition_old
-              , OperationDetail & operationdetail
-              )
-{
-	return true ;
-}
-
-bool hfs::copy( const Glib::ustring & src_part_path,
-		const Glib::ustring & dest_part_path,
-		OperationDetail & operationdetail )
-{
-	return true ;
-}
-
 bool hfs::check_repair( const Partition & partition, OperationDetail & operationdetail )
 {
 	//FIXME: find out what the returnvalue is in case of modified.. also check what the -a flag does.. (there is no manpage)
 	return ! execute_command( "hfsck -v " + partition .get_path(), operationdetail ) ;
 }
 
-bool hfs::remove( const Partition & partition, OperationDetail & operationdetail )
-{
-	return true ;
-}
-
 } //GParted
