@@ -64,10 +64,6 @@ FS linux_swap::get_filesystem_support()
 	return fs ;
 }
 
-void linux_swap::set_used_sectors( Partition & partition ) 
-{
-}
-
 void linux_swap::read_label( Partition & partition )
 {
 	if ( ! Utils::execute_command( "swaplabel " + partition .get_path(), output, error, true ) )
@@ -153,8 +149,8 @@ bool linux_swap::move( const Partition & partition_new
 	return true ;
 }
 
-bool linux_swap::copy( const Glib::ustring & src_part_path,
-		       const Glib::ustring & dest_part_path,
+bool linux_swap::copy( const Partition & src_part,
+		       Partition & dest_part,
 		       OperationDetail & operationdetail )
 {
 	//Since linux-swap does not contain data, do not actually copy the partition
@@ -172,14 +168,4 @@ bool linux_swap::copy( const Glib::ustring & src_part_path,
 	return true ;
 }
 
-bool linux_swap::check_repair( const Partition & partition, OperationDetail & operationdetail )
-{
-	return true ;
-}
-
-bool linux_swap::remove( const Partition & partition, OperationDetail & operationdetail )
-{
-	return true ;
-}
-
 } //GParted
