@@ -25,8 +25,6 @@ int main( int argc, char *argv[] )
 {
 	//initialize thread system
 	Glib::thread_init() ;
-	gdk_threads_init();
-	gdk_threads_enter();
 	GParted::GParted_Core::mainthread = Glib::Thread::self();
 	
 	Gtk::Main kit( argc, argv ) ;
@@ -51,10 +49,7 @@ int main( int argc, char *argv[] )
 	}
 
 	//deal with arguments..
-	std::vector<Glib::ustring> user_devices ;
-	
-	for ( int t = 1 ; t < argc ; t++ )
-		user_devices .push_back( argv[ t ] ) ;
+	std::vector<Glib::ustring> user_devices(argv + 1, argv + argc);
 	
 	GParted::Win_GParted win_gparted( user_devices ) ; 
 	Gtk::Main::run( win_gparted ) ;
