@@ -149,50 +149,32 @@ bool reiserfs::write_uuid( const Partition & partition, OperationDetail & operat
 
 bool reiserfs::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "mkreiserfs -f --label \"" + new_partition .get_label() + "\" " + new_partition .get_path(), operationdetail ) ;
+	return ! execute_command( "mkreiserfs -f --label \"" + new_partition.get_label() +
+				  "\" " + new_partition.get_path(), operationdetail,
+				  false, true );
 }
 
 bool reiserfs::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
 { 
-	Glib::ustring str_temp = "echo y | resize_reiserfs " + partition_new .get_path() ;
-	
+	Glib::ustring size = "" ;
 	if ( ! fill_partition )
 	{
-		str_temp += " -s " ;
-		str_temp += Utils::num_to_str( Utils::round( Utils::sector_to_unit(
-				partition_new .get_sector_length(), partition_new .sector_size, UNIT_BYTE ) ) -1 ) ;
+		size = " -s " + Utils::num_to_str( Utils::round( Utils::sector_to_unit(
+		                   partition_new .get_sector_length(), partition_new .sector_size, UNIT_BYTE ) ) -1 ) ;
 	}
+	Glib::ustring cmd = "sh -c 'echo y | resize_reiserfs" + size + " " + partition_new .get_path() + "'" ;
 
-	exit_status = execute_command( str_temp, operationdetail ) ;
+	exit_status = execute_command( cmd, operationdetail ) ;
 
 	return ( exit_status == 0 || exit_status == 256 ) ;
 }
 
-bool reiserfs::move( const Partition & partition_new
-                   , const Partition & partition_old
-                   , OperationDetail & operationdetail
-                   )
-{
-	return true ;
-}
-
-bool reiserfs::copy( const Glib::ustring & src_part_path,
-		     const Glib::ustring & dest_part_path,
-		     OperationDetail & operationdetail )
-{	
-	return true ;
-}
-
 bool reiserfs::check_repair( const Partition & partition, OperationDetail & operationdetail )
 {
-	exit_status = execute_command( "reiserfsck --yes --fix-fixable --quiet " + partition .get_path(), operationdetail ) ;
+	exit_status = execute_command( "reiserfsck --yes --fix-fixable --quiet " + partition.get_path(),
+				       operationdetail, false, true );
 	
 	return ( exit_status == 0 || exit_status == 1 || exit_status == 256 ) ;
 }
 
-bool reiserfs::remove( const Partition & partition, OperationDetail & operationdetail )
-{
-	return true ;
-}
-
 } //GParted
