@@ -164,11 +164,11 @@ bool xfs::write_uuid( const Partition & partition, OperationDetail & operationde
 
 bool xfs::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
-	//mkfs.xfs will not create file system if label is longer than 12 characters, hence truncation.
-	Glib::ustring label = new_partition .get_label() ;
-	if( label .length() > 12 )
-		label = label.substr( 0, 12 ) ;
-	return ! execute_command( "mkfs.xfs -f -L \"" + label + "\" " + new_partition .get_path(), operationdetail ) ;
+	return ! execute_command( "mkfs.xfs -f -L \"" + new_partition.get_label() +
+				  "\" " + new_partition.get_path(),
+				  operationdetail,
+				  false,
+				  true );
 }
 
 bool xfs::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
@@ -179,14 +179,14 @@ bool xfs::resize( const Partition & partition_new, OperationDetail & operationde
 	if ( mount_point .empty() )
 		return false ;
 
-	success &= ! execute_command_timed( "mount -v -t xfs " + partition_new .get_path() + " " + mount_point,
-	                                    operationdetail ) ;
+	success &= ! execute_command( "mount -v -t xfs " + partition_new .get_path() + " " + mount_point,
+				      operationdetail, true ) ;
 
 	if ( success )
 	{
-		success &= ! execute_command_timed( "xfs_growfs " + mount_point, operationdetail ) ;
+		success &= ! execute_command( "xfs_growfs " + mount_point, operationdetail, true ) ;
 
-		success &= ! execute_command_timed( "umount -v " + mount_point, operationdetail ) ;
+		success &= ! execute_command( "umount -v " + mount_point, operationdetail, true ) ;
 	}
 
 	rm_temp_dir( mount_point, operationdetail ) ;
@@ -194,21 +194,13 @@ bool xfs::resize( const Partition & partition_new, OperationDetail & operationde
 	return success ;
 }
 
-bool xfs::move( const Partition & partition_new
-              , const Partition & partition_old
-              , OperationDetail & operationdetail
-              )
-{
-	return true ;
-}
-
-bool xfs::copy( const Glib::ustring & src_part_path,
-		const Glib::ustring & dest_part_path,
+bool xfs::copy( const Partition & src_part,
+		Partition & dest_part,
 		OperationDetail & operationdetail )
 {
 	bool success = true ;
 
-	success &= ! execute_command_timed( "mkfs.xfs -f " + dest_part_path, operationdetail ) ;
+	success &= ! execute_command( "mkfs.xfs -f " + dest_part.get_path(), operationdetail, true, true );
 	if ( ! success )
 		return false ;
 
@@ -223,24 +215,24 @@ bool xfs::copy( const Glib::ustring & src_part_path,
 		return false ;
 	}
 
-	success &= ! execute_command_timed( "mount -v -t xfs -o noatime,ro " + src_part_path +
-	                                    " " + src_mount_point, operationdetail ) ;
+	success &= ! execute_command( "mount -v -t xfs -o noatime,ro " + src_part.get_path() +
+				      " " + src_mount_point, operationdetail, true ) ;
 
 	if ( success )
 	{
-		success &= ! execute_command_timed( "mount -v -t xfs " + dest_part_path +
-		                                    " " + dest_mount_point, operationdetail ) ;
+		success &= ! execute_command( "mount -v -t xfs " + dest_part.get_path() +
+					      " " + dest_mount_point, operationdetail, true ) ;
 
 		if ( success )
 		{
-			success &= ! execute_command_timed( "xfsdump -J - " + src_mount_point +
-			                                    " | xfsrestore -J - " + dest_mount_point,
-			                                    operationdetail ) ;
+			success &= ! execute_command( "sh -c 'xfsdump -J - " + src_mount_point +
+						      " | xfsrestore -J - " + dest_mount_point + "'",
+						      operationdetail, true, true );
 
-			success &= ! execute_command_timed( "umount -v " + dest_part_path, operationdetail ) ;
+			success &= ! execute_command( "umount -v " + dest_part.get_path(), operationdetail, true ) ;
 		}
 
-		success &= ! execute_command_timed( "umount -v " + src_part_path, operationdetail ) ;
+		success &= ! execute_command( "umount -v " + src_part.get_path(), operationdetail, true ) ;
 	}
 
 	rm_temp_dir( dest_mount_point, operationdetail ) ;
@@ -252,12 +244,8 @@ bool xfs::copy( const Glib::ustring & src_part_path,
 
 bool xfs::check_repair( const Partition & partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "xfs_repair -v " + partition .get_path(), operationdetail ) ;
-}
-
-bool xfs::remove( const Partition & partition, OperationDetail & operationdetail )
-{
-	return true ;
+	return ! execute_command( "xfs_repair -v " + partition .get_path(), operationdetail,
+				  false, true );
 }
 
 } //GParted
